@@ -72,7 +72,8 @@ struct _MetaUIFrame
   int text_height;
   char *title; /* NULL once we have a layout */
   guint expose_delayed : 1;
-
+  guint shape_applied : 1;
+  
   /* FIXME get rid of this, it can just be in the MetaFrames struct */
   MetaFrameControl prelit_control;
 };
@@ -102,7 +103,8 @@ GType        meta_frames_get_type               (void) G_GNUC_CONST;
 MetaFrames *meta_frames_new (int screen_number);
 
 void meta_frames_manage_window (MetaFrames *frames,
-                                Window      xwindow);
+                                Window      xwindow,
+				GdkWindow  *window);
 void meta_frames_unmanage_window (MetaFrames *frames,
                                   Window      xwindow);
 void meta_frames_set_title (MetaFrames *frames,
@@ -127,8 +129,14 @@ void meta_frames_unflicker_bg (MetaFrames *frames,
 void meta_frames_apply_shapes (MetaFrames *frames,
                                Window      xwindow,
                                int         new_window_width,
-                               int         new_window_height);
-
+                               int         new_window_height,
+                               gboolean    window_has_shape);
+void meta_frames_move_resize_frame (MetaFrames *frames,
+				    Window      xwindow,
+				    int         x,
+				    int         y,
+				    int         width,
+				    int         height);
 void meta_frames_queue_draw (MetaFrames *frames,
                              Window      xwindow);
 
