@@ -63,8 +63,8 @@ static MenuItem menuitems[] = {
   { 0, NULL, FALSE, NULL }, /* separator */
   { META_MENU_OP_DELETE, METACITY_STOCK_DELETE, FALSE, N_("_Close") },
   { META_MENU_OP_WORKSPACES, NULL, FALSE, NULL }, /* separator */
-  { META_MENU_OP_STICK, NULL, FALSE, N_("Put on _All Workspaces") },
-  { META_MENU_OP_UNSTICK, NULL, FALSE,  N_("Only on _This Workspace") },
+  { META_MENU_OP_STICK, NULL, FALSE, N_("_Always on Visible Workspace") },
+  { META_MENU_OP_UNSTICK, NULL, FALSE,  N_("_Only on This Workspace") },
   { META_MENU_OP_MOVE_LEFT, NULL, FALSE, N_("Move to Workspace _Left") },
   { META_MENU_OP_MOVE_RIGHT, NULL, FALSE, N_("Move to Workspace R_ight") },
   { META_MENU_OP_MOVE_UP, NULL, FALSE, N_("Move to Workspace _Up") },
@@ -421,10 +421,8 @@ meta_window_menu_new   (MetaFrames         *frames,
   else
     meta_verbose ("not creating workspace menu\n");
   
-  gtk_signal_connect (GTK_OBJECT (menu->menu),
-                      "selection_done",
-                      GTK_SIGNAL_FUNC (menu_closed),
-                      menu);  
+  g_signal_connect (menu->menu, "selection_done",
+                    G_CALLBACK (menu_closed), menu);  
 
   return menu;
 }
