@@ -280,9 +280,15 @@ topic_name (MetaDebugTopic topic)
       return "PREFS";
     case META_DEBUG_GROUPS:
       return "GROUPS";
+    case META_DEBUG_RESIZING:
+      return "RESIZING";
+    case META_DEBUG_SHAPES:
+      return "SHAPES";
+    case META_DEBUG_COMPOSITOR:
+      return "COMPOSITOR";
     }
 
-  return "Window manager";
+  return "WM";
 }
 
 static int sync_count = 0;
@@ -437,7 +443,7 @@ meta_unsigned_long_hash  (gconstpointer v)
   gulong val = * (const gulong *) v;
 
   /* I'm not sure this works so well. */
-#if G_SIZEOF_LONG > 4
+#if GLIB_SIZEOF_LONG > 4
   return (guint) (val ^ (val >> 32));
 #else
   return val;
