@@ -170,6 +170,26 @@ reload_net_wm_pid (MetaWindow    *window,
     }
 }
 
+static void
+init_net_wm_user_time (MetaDisplay   *display,
+                       Atom           property,
+                       MetaPropValue *value)
+{
+  value->type = META_PROP_VALUE_CARDINAL;
+  value->atom = display->atom_net_wm_user_time;
+}
+
+static void
+reload_net_wm_user_time (MetaWindow    *window,
+                         MetaPropValue *value)
+{
+  if (value->type != META_PROP_VALUE_INVALID)
+    {
+      gulong cardinal = value->v.cardinal;
+      meta_window_set_user_time (window, cardinal);
+    }
+}
+
 static void
 set_window_title (MetaWindow *window,
                   const char *title)
@@ -354,44 +374,10 @@ reload_net_wm_desktop (MetaWindow    *window,
     }
 }
 
-static void
-init_win_workspace (MetaDisplay   *display,
-                    Atom           property,
-                    MetaPropValue *value)
-{
-  value->type = META_PROP_VALUE_CARDINAL;
-  value->atom = display->atom_win_workspace;
-}
-
-static void
-reload_win_workspace (MetaWindow    *window,
-                      MetaPropValue *value)
-{
-  if (value->type != META_PROP_VALUE_INVALID)
-    {
-      meta_topic (META_DEBUG_PLACEMENT,
-                  "Read legacy GNOME workspace prop %d for %s\n",
-                  (int) value->v.cardinal, window->desc);
-
-      if (window->initial_workspace_set)
-        {
-          meta_topic (META_DEBUG_PLACEMENT,
-                      "Ignoring legacy GNOME workspace prop %d for %s as we already set initial workspace\n",
-                      (int) value->v.cardinal, window->desc);          
-        }
-      else
-        {
-          window->initial_workspace_set = TRUE;
-          window->initial_workspace = value->v.cardinal;
-        }
-    }
-}
-
-
 static void
 init_net_startup_id (MetaDisplay   *display,
-                  Atom           property,
-                  MetaPropValue *value)
+                     Atom           property,
+                     MetaPropValue *value)
 {
   value->type = META_PROP_VALUE_UTF8;
   value->atom = display->atom_net_startup_id;
@@ -419,7 +405,7 @@ init_update_counter (MetaDisplay   *display,
                      MetaPropValue *value)
 {
   value->type = META_PROP_VALUE_SYNC_COUNTER;
-  value->atom = display->atom_metacity_update_counter;
+  value->atom = display->atom_net_wm_sync_request_counter;
 }
 
 static void
@@ -431,9 +417,9 @@ reload_update_counter (MetaWindow    *window,
 #ifdef HAVE_XSYNC
       XSyncCounter counter = value->v.xcounter;
 
-      window->update_counter = counter;
-      meta_verbose ("Window has _METACITY_UPDATE_COUNTER 0x%lx\n",
-                    window->update_counter);
+      window->sync_request_counter = counter;
+      meta_verbose ("Window has _NET_WM_SYNC_REQUEST_COUNTER 0x%lx\n",
+                    window->sync_request_counter);
 #endif
     }
 }
@@ -848,7 +834,7 @@ reload_wm_hints (MetaWindow    *window,
 
 
 
-#define N_HOOKS 25
+#define N_HOOKS 24
 
 void
 meta_display_init_window_prop_hooks (MetaDisplay *display)
@@ -878,6 +864,11 @@ meta_display_init_window_prop_hooks (MetaDisplay *display)
   hooks[i].reload_func = reload_net_wm_pid;
   ++i;
 
+  hooks[i].property = display->atom_net_wm_user_time;
+  hooks[i].init_func = init_net_wm_user_time;
+  hooks[i].reload_func = reload_net_wm_user_time;
+  ++i;
+
   hooks[i].property = display->atom_net_wm_name;
   hooks[i].init_func = init_net_wm_name;
   hooks[i].reload_func = reload_net_wm_name;
@@ -938,27 +929,17 @@ meta_display_init_window_prop_hooks (MetaDisplay *display)
   hooks[i].reload_func = NULL;
   ++i;
 
-  hooks[i].property = display->atom_win_layer;
-  hooks[i].init_func = NULL;
-  hooks[i].reload_func = NULL;
-  ++i;
-
   hooks[i].property = display->atom_net_wm_desktop;
   hooks[i].init_func = init_net_wm_desktop;
   hooks[i].reload_func = reload_net_wm_desktop;
   ++i;
 
-  hooks[i].property = display->atom_win_workspace;
-  hooks[i].init_func = init_win_workspace;
-  hooks[i].reload_func = reload_win_workspace;
-  ++i;
-
   hooks[i].property = display->atom_net_wm_strut;
   hooks[i].init_func = NULL;
   hooks[i].reload_func = NULL;
   ++i;
 
-  hooks[i].property = display->atom_win_hints;
+  hooks[i].property = display->atom_net_wm_strut_partial;
   hooks[i].init_func = NULL;
   hooks[i].reload_func = NULL;
   ++i;
@@ -968,7 +949,7 @@ meta_display_init_window_prop_hooks (MetaDisplay *display)
   hooks[i].reload_func = reload_net_startup_id;
   ++i;
 
-  hooks[i].property = display->atom_metacity_update_counter;
+  hooks[i].property = display->atom_net_wm_sync_request_counter;
   hooks[i].init_func = init_update_counter;
   hooks[i].reload_func = reload_update_counter;
   ++i;
